clear all;
cla;
clc;

data = xlsread('test_5.xlsx');

time = data(:,1);
pwm = data(:,3);
temp = data(:,5);

for n = 1:size(temp)
    if isnan(temp(n)) == 1
        temp(n) = buffer;
    else
        buffer = temp(n);
    end
end

rpm = data(:,6);

for n = 1:size(rpm)
    if isnan(rpm(n)) == 1
        rpm(n) = buffer;
    else
        buffer = rpm(n);
    end
end

omega = 2*pi/60 .* rpm;
pwr = data(:,7);

for n = 1:size(pwr)
    if isnan(pwr(n)) == 1
        pwr(n) = buffer;
    else
        buffer = pwr(n);
    end
end

thrust = data(:,9);

ss = [62, 76, 86, 108, 116, 136, 143, 148];

for n = 1:size(ss,2)
    pwm_ss(n) = pwm(ss(n)*10);
    omega_ss(n) = omega(ss(n)*10);
    thrust_ss(n) = thrust(ss(n)*10);
    pwr_ss(n) = pwr(ss(n)*10);
end

pwm_pts = 1250:2000;

[omega_r,omega_m, omega_b] = regression(pwm_ss, omega_ss);
omega_pts = omega_m .* pwm_pts + omega_b;
subplot(4,1,1)
plot(pwm_pts, omega_pts, '-', pwm_ss, omega_ss, '.');
xlim([1250 2000]);
ylim([0 15000]);
title(['omega = ' num2str(omega_m) '(pwm) ' num2str(omega_b)]);
xlabel('pwm (us)');
ylabel('omega (rad/s)');

[thrust_r,thrust_m, thrust_b] = regression(pwm_ss, thrust_ss);
thrust_pts = thrust_m .* pwm_pts + thrust_b;
subplot(4,1,2)
plot(pwm_pts, thrust_pts, '-', pwm_ss, thrust_ss, '.');
xlim([1250 2000]);
title(['thrust = ' num2str(thrust_m) '(pwm) ' num2str(thrust_b)]);
xlabel('pwm (us)');
ylabel('thrust (N)');

[pwr_r,pwr_m, pwr_b] = regression(pwm_ss, pwr_ss);
pwr_pts = pwr_m .* pwm_pts + pwr_b;
subplot(4,1,3)
plot(pwm_pts, pwr_pts, '-', pwm_ss, pwr_ss, '.');
xlim([1250 2000]);
title(['power = ' num2str(pwr_m) '(pwm) ' num2str(pwr_b)]);
xlabel('pwm (us)');
ylabel('power (W)');

[omega2_r,omega2_m, omega2_b] = regression(thrust_ss, omega_ss);
omega2_pts = omega2_m .* thrust_pts + omega2_b;
subplot(4,1,4)
plot(thrust_pts, omega2_pts, '-', thrust_ss, omega_ss, '.');
xlim([min(thrust_pts) max(thrust_pts)]);
title(['omega = ' num2str(omega2_m) '(thrust) +' num2str(omega2_b)]);
xlabel('thrust (N)');
ylabel('omega (rad/s)');

figure;

subplot(4,1,1);
[sub1, pwm_plot, omega_plot] = plotyy(time, pwm, time, omega);
xlabel('time (s)');
ylabel(sub1(1), 'pwm (us)');
ylabel(sub1(2), 'omega (rad/s)');
ylim(sub1(2), [0 12000]);
grid(sub1(1), 'on');
grid(sub1(2), 'on');

subplot(4,1,2);
[sub2, pwm2_plot, thrust_plot] = plotyy(time, pwm, time, thrust);
xlabel('time (s)');
ylabel(sub2(1), 'pwm (us)');
ylabel(sub2(2), 'thrust (N)');
ylim(sub2(2), [0 110]);
grid(sub2(1), 'on');
grid(sub2(2), 'on');

subplot(4,1,3);
[sub3, pwm3_plot, pwr_plot] = plotyy(time, pwm, time, pwr);
xlabel('time (s)');
ylabel(sub3(1), 'pwm (us)');
ylabel(sub3(2), 'power (W)');
ylim(sub3(2), [0 400]);
grid(sub3(1), 'on');
grid(sub3(2), 'on');

subplot(4,1,4);
[sub4, thrust2_plot, omega2_plot] = plotyy(time, thrust, time, omega);
xlabel('time (s)');
ylabel(sub4(1), 'thrust (N)');
ylabel(sub4(2), 'omega (rad/s)');
ylim(sub4(1), [0 110]);
ylim(sub4(2), [0 12000]);
grid(sub4(1), 'on');
grid(sub4(2), 'on');

% figure;
% plot(time, pwm);
% figure;
% plot(time, pwr);
% figure;
% plot(time, temp);
% figure;
% plot(time, rpm);
% figure;
% plot(time, thrust);
